@@ -58,7 +58,7 @@ class AnalysisForm(forms.Form):
                             ('VB','Vitevitch & Luce from Buckeye corpus words'))
     measure = forms.CharField(label='Measure')
     DispersionFromAH = forms.BooleanField(initial=False,required=False,label="Dispersion from a speaker's AH tokens")
-    measure.widget = forms.Select(choices=mChoices)
+    measure.widget = forms.Select(choices=M_CHOICES)
     placeInDialog = forms.BooleanField(initial=True,required=False,label='Time since beginning of dialog')
     speakingRates = forms.BooleanField(initial=True,required=False,label='Speaking rates')
     contextProbs = forms.BooleanField(initial=True,required=False,label='Contextual probabilities')
